'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactJsonTree = require('react-json-tree');

var _reactJsonTree2 = _interopRequireDefault(_reactJsonTree);

var _themeable = require('./themeable');

var _themeable2 = _interopRequireDefault(_themeable);

var _javascriptStringify = require('javascript-stringify');

var _javascriptStringify2 = _interopRequireDefault(_javascriptStringify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function stringifyAndShrink(val) {
  var str = (0, _javascriptStringify2.default)(val);
  if (val === null) {
    return 'null';
  } else if (typeof val === 'undefined') {
    return 'undefined';
  }

  return str.length > 22 ? str.substr(0, 15) + '…' + str.substr(-5) : str;
}

function prepareDelta(value) {
  if (value && value._t === 'a') {
    var res = {};
    for (var key in value) {
      if (key !== '_t') {
        if (key[0] === '_' && !value[key.substr(1)]) {
          res[key.substr(1)] = value[key];
        } else if (value['_' + key]) {
          res[key] = [value['_' + key][0], value[key][0]];
        } else if (!value['_' + key] && key[0] !== '_') {
          res[key] = value[key];
        }
      }
    }
    return res;
  }

  return value;
}

function _valueRenderer(raw, value, createTheme) {
  function renderSpan(name, body) {
    return _react2.default.createElement(
      'span',
      (0, _extends3.default)({ key: name }, createTheme('diff', name)),
      body
    );
  }

  if (Array.isArray(value)) {
    switch (value.length) {
      case 1:
        return _react2.default.createElement(
          'span',
          createTheme('diffWrap'),
          renderSpan('diffAdd', stringifyAndShrink(value[0]))
        );
      case 2:
        return _react2.default.createElement(
          'span',
          createTheme('diffWrap'),
          renderSpan('diffUpdateFrom', stringifyAndShrink(value[0])),
          renderSpan('diffUpdateArrow', ' => '),
          renderSpan('diffUpdateTo', stringifyAndShrink(value[1]))
        );
      case 3:
        return _react2.default.createElement(
          'span',
          createTheme('diffWrap'),
          renderSpan('diffRemove', stringifyAndShrink(value[0]))
        );
    }
  }

  return raw;
}

var JSONDiff = function JSONDiff(_ref) {
  var delta = _ref.delta;
  var theme = _ref.theme;
  var base16Theme = _ref.base16Theme;
  var props = (0, _objectWithoutProperties3.default)(_ref, ['delta', 'theme', 'base16Theme']);

  var createTheme = (0, _themeable2.default)(theme);

  return _react2.default.createElement(_reactJsonTree2.default, (0, _extends3.default)({}, props, {
    theme: base16Theme,
    data: delta,
    getItemString: function getItemString() {
      return '';
    },
    valueRenderer: function valueRenderer(raw, value) {
      return _valueRenderer(raw, value, createTheme);
    },
    postprocessValue: prepareDelta,
    isCustomNode: function isCustomNode(value) {
      return Array.isArray(value);
    },
    expandAll: true,
    hideRoot: true }));
};

exports.default = JSONDiff;